--[[
##	Name: HideBlizzard 1.0.66
##	Author: Gendr
##	Description: Hides blizzard frames
##	License: All Rights Reserved
##
##	LATEST CHANGES(08/13/2012):
##	* 4.3 Compatable only, disables on MOP beta
##	* Options - Expanded version display
##	* ActionBar\\XP Bar - put max level check in
##	* Player\\ArmoredMan - Fixed graphical error when player module was enabled
]]
HideBlizzard = LibStub("AceAddon-3.0"):NewAddon("HideBlizzard", "AceConsole-3.0", "AceEvent-3.0", "AceHook-3.0")
HideBlizzard:SetEnabledState(true)
HideBlizzard:SetDefaultModuleState(false)
HideBlizzard:SetDefaultModuleLibraries("AceEvent-3.0")

local mop_500 = select(4, GetBuildInfo()) >= 50000

local MAJOR, MINOR = "HideBlizzard", 66
local RootVer = GetAddOnMetadata("HideBlizzard", "Version").."."..tonumber(MINOR)
local RootName = "|cff33ff99"..tostring(MAJOR).."|r "

local db
local defaults = {
	profile = {
		modules = {
			["ActionBar"] = false,
			["Buttons"] = false,
			["Pet"] = false,
			["Player"] = false,
			["SpecialFrames"] = false,
			["Target"] = false,
		},
	},
}

local db
local defaults = {
	profile = {
		modules = {
			["*"] = false,
		},
	},
}

local reset_vers = {
	"1.0.59",
	"1.0.63",
	"1.0.65",
}

function HideBlizzard:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("HideBlizzardDB", defaults)
	self.db.RegisterCallback(self, "OnProfileChanged", "UpdateView")
	self.db.RegisterCallback(self, "OnProfileCopied", "UpdateView")
	self.db.RegisterCallback(self, "OnProfileReset", "UpdateView")
	db = self.db.profile

	local lastUpdate = 0
	local waitFrame = CreateFrame("Frame")
	waitFrame:SetScript("OnUpdate", function(self, elapsed)
		lastUpdate = lastUpdate + elapsed
		if(lastUpdate > 3) then
			if not db.Version then
				db.Version = RootVer
				print(RootName.."Welcome! Type /hb for options")
			elseif db.Version ~= RootVer then
				for k in pairs(reset_vers) do
					if db.Version:match(tostring(k)) then
						print(RootName.."|cffFF3333Notice: You need to ReloadUI() for HideBlizzard to work|r")
						HideBlizzardDB = {}
					end
					waitFrame:SetScript("OnUpdate", nil)
				end
				db.Version = RootVer
				print(string.format(RootName.."Updated to version |cff00ff66%s|r Type /hb for options", db.Version))
			end
			lastUpdate = 0
			waitFrame:SetScript("OnUpdate", nil)
		end
	end)
end

function HideBlizzard:OnEnable()
	if mop_500 then
		print(RootName.."cannot be enabled on MOP beta realms yet! disabling..")
		HideBlizzard:SetEnabledState(false)
		wipe(HideBlizzardDB)
		HideBlizzard = nil
		UIParnet:DisableAddOn("HideBlizzard")
		return
	end

	self:RegisterOptions()
end

function HideBlizzard:OnDisable()
	for k,v in self:IterateModules() do
		if self:GetModuleEnabled(k) then
			self:DisableModule(k)
		end
	end
	HideBlizzard:SetEnabledState(false)
end

-- @Mapster func
function HideBlizzard:GetModuleEnabled(module)
	return self.db.profile.modules[module]
end
-- @Mapster func
function HideBlizzard:SetModuleEnabled(module, value)
	local old = HideBlizzard.db.profile.modules[module]
	HideBlizzard.db.profile.modules[module] = value
	if old ~= value then
		if value then
			HideBlizzard:EnableModule(module)
		else
			HideBlizzard:DisableModule(module)
		end
	end
end
-- @Mapster func
function HideBlizzard:UpdateView()
	for k,v in self:IterateModules() do
		if self:GetModuleEnabled(k) and not v:IsEnabled() then
			self:EnableModule(k)
		elseif not self:GetModuleEnabled(k) and v:IsEnabled() then
			self:DisableModule(k)
		end
		if(type(v.UpdateView) == "function") then
			v:UpdateView()
		end
	end
end
