local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")

local version = GetAddOnMetadata("HideBlizzard", "Version")
local curse_ver = GetAddOnMetadata("HideBlizzard", "X-Curse-Packaged-Version")
local wowint_ver = GetAddOnMetadata("HideBlizzard", "X-WoWI-Version")

local options, moduleOptions = nil, {}
local function main_options()
	if not options then
		options = {
			type = "group",
			name = "HideBlizzard",
			childGroups = "tab",
			get = function() get(info)
						local key = info[#info] 
						return HideBlizzard.db.profile[key]
					end,
			set = function() set(info, value)
						local key = info[#info]
						HideBlizzard.db.profile[key] = value
						HideBlizzard:UpdateView()
					end,
			args = {
				header = {
					type = "description",
					name = " |cffFF3333Your Version: |r"..version,
					order = 1,
					fontSize = "medium",
					width="full",
				},
				header2 = {
					type = "description",
					name = " |cffFFA500Curse Version: |r"..curse_ver,
					order = 2,
					fontSize = "medium",
					width="full",
				},
				header3 = {
					type = "description",
					name = " |cffFFFF00Wowinterface Version: |r"..wowint_ver,
					order = 3,
					fontSize = "medium",
					width="full",
				},
				space = {
					type = "description",
					name = "",
					order = 4,
					width="full",
				},
				header4 = {
					type = "description",
					name = function() 
						if version == curse_ver and wowint_ver then
							return"|cff00FF00 All versions are up-to-date!|r"
						else 
							return"|cffFF0000 Your NOT up-to-date please download a NEW copy of HideBlizzard to ensure your getting the latest enhancements and fixes|r"
						end
					end,
					order = 5,
					fontSize = "medium",
					width="full",
				},
				space2 = {
					type = "description",
					name = "",
					order = 6,
					width="full",
				},
				reset = {
					type = "execute",
					name = "reset global database",
					order = -1,
					confirm = true,
					func = function() 
						wipe(HideBlizzardDB)
						print("|cff33ff99HideBlizzard|r Database has been reset! Changes will take effect when you next login")
					end,
				},
			},
		}
		options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(HideBlizzard.db)
		options.args.profiles.order = -2
		for k,v in pairs(moduleOptions) do
			options.args[k] = type(v) == "function" and v() or v
		end
	end
	return options
end

local blizz_options = {
	type = "group",
	args = {
		bo = {
			type = "group",
			name = "HideBlizzard_Blizzard",
			args = {
				boo = {
					type = "execute",
					name = "Standalone Options",
					order = 1,
					desc = "Open options!",
					func = function()
						HideUIPanel(InterfaceOptionsFrame)
						HideUIPanel(GameMenuFrame)
						AceConfigDialog:Open("HideBlizzard")
					end,
				},
			},
		},
	},
}

function HideBlizzard:RegisterOptions()
	AceConfigRegistry:RegisterOptionsTable("HideBlizzard", main_options)
	AceConfigRegistry:RegisterOptionsTable("HideBlizzard_Blizzard", blizz_options)
	AceConfigDialog:AddToBlizOptions("HideBlizzard_Blizzard", nil, nil, "bo")

	local function open()
		AceConfigDialog:Open("HideBlizzard")
	end
	self:RegisterChatCommand("hb", open)
	self:RegisterChatCommand("hideblizz", open)
	self:RegisterChatCommand("hideblizzard", open)

	self:RegisterEvent("PLAYER_REGEN_DISABLED", function()
		if(InCombatLockdown()) then
			AceConfigDialog:Close("HideBlizzard")
		end
	end)
end

function HideBlizzard:RegisterModuleOptions(name, optionTbl, displayName)
	moduleOptions[name] = optionTbl
end
